@@ -5,9 +5,6 @@ from torch import nn
 
 
 class ResidualBlock(nn.Module):
-    def __init__(self) -> None:
-        super().__init__()
-
     def forward(
         self,
         x: torch.Tensor,
